summaryrefslogtreecommitdiff
path: root/lib/canonicalize.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
committerPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
commitab2edb9e3307a172487bb16edcaf79600bf9ebea (patch)
tree891357990f461f806713fa4cb52c1b9bb91d1ba3 /lib/canonicalize.c
parent1e6b9bd047bdaf17291f87e44a218814dd6560f5 (diff)
downloadcoreutils-ab2edb9e3307a172487bb16edcaf79600bf9ebea.tar.xz
Don't use "path" or "filename" to mean "file name"
in comments or local variable names.
Diffstat (limited to 'lib/canonicalize.c')
-rw-r--r--lib/canonicalize.c78
1 files changed, 40 insertions, 38 deletions
diff --git a/lib/canonicalize.c b/lib/canonicalize.c
index 822fe6f75..571fa19e2 100644
--- a/lib/canonicalize.c
+++ b/lib/canonicalize.c
@@ -48,7 +48,7 @@ void free ();
#include <stddef.h>
#include "cycle-check.h"
-#include "path-concat.h"
+#include "filenamecat.h"
#include "stat-macros.h"
#include "xalloc.h"
#include "xgetcwd.h"
@@ -62,8 +62,8 @@ void free ();
#if !HAVE_CANONICALIZE_FILE_NAME
/* Return the canonical absolute name of file NAME. A canonical name
- does not contain any `.', `..' components nor any repeated path
- separators ('/') or symlinks. All path components must exist.
+ does not contain any `.', `..' components nor any repeated file name
+ separators ('/') or symlinks. All components must exist.
The result is malloc'd. */
char *
@@ -89,7 +89,7 @@ canonicalize_file_name (const char *name)
/* All known hosts with resolvepath (e.g. Solaris 7) don't turn
relative names into absolute ones, so prepend the working
- directory if the path is not absolute. */
+ directory if the file name is not absolute. */
if (name[0] != '/')
{
char *wd;
@@ -97,7 +97,7 @@ canonicalize_file_name (const char *name)
if (!(wd = xgetcwd ()))
return NULL;
- extra_buf = path_concat (wd, name, NULL);
+ extra_buf = file_name_concat (wd, name, NULL);
name = extra_buf;
free (wd);
}
@@ -135,15 +135,17 @@ canonicalize_file_name (const char *name)
#endif /* !HAVE_CANONICALIZE_FILE_NAME */
/* Return the canonical absolute name of file NAME. A canonical name
- does not contain any `.', `..' components nor any repeated path
- separators ('/') or symlinks. Whether path components must exist
+ does not contain any `.', `..' components nor any repeated file name
+ separators ('/') or symlinks. Whether components must exist
or not depends on canonicalize mode. The result is malloc'd. */
char *
canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
{
- char *rpath, *dest, *extra_buf = NULL;
- const char *start, *end, *rpath_limit;
+ char *rname, *dest, *extra_buf = NULL;
+ char const *start;
+ char const *end;
+ char const *rname_limit;
size_t extra_len = 0;
struct cycle_check_state cycle_state;
@@ -161,38 +163,38 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
if (name[0] != '/')
{
- rpath = xgetcwd ();
- if (!rpath)
+ rname = xgetcwd ();
+ if (!rname)
return NULL;
- dest = strchr (rpath, '\0');
- if (dest - rpath < PATH_MAX)
+ dest = strchr (rname, '\0');
+ if (dest - rname < PATH_MAX)
{
- char *p = xrealloc (rpath, PATH_MAX);
- dest = p + (dest - rpath);
- rpath = p;
- rpath_limit = rpath + PATH_MAX;
+ char *p = xrealloc (rname, PATH_MAX);
+ dest = p + (dest - rname);
+ rname = p;
+ rname_limit = rname + PATH_MAX;
}
else
{
- rpath_limit = dest;
+ rname_limit = dest;
}
}
else
{
- rpath = xmalloc (PATH_MAX);
- rpath_limit = rpath + PATH_MAX;
- rpath[0] = '/';
- dest = rpath + 1;
+ rname = xmalloc (PATH_MAX);
+ rname_limit = rname + PATH_MAX;
+ rname[0] = '/';
+ dest = rname + 1;
}
cycle_check_init (&cycle_state);
for (start = end = name; *start; start = end)
{
/* Skip sequence of multiple path-separators. */
while (*start == '/')
++start;
- /* Find end of path component. */
+ /* Find end of component. */
for (end = start; *end && *end != '/'; ++end)
/* Nothing. */;
@@ -203,7 +205,7 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
else if (end - start == 2 && start[0] == '.' && start[1] == '.')
{
/* Back up to previous component, ignore if at root already. */
- if (dest > rpath + 1)
+ if (dest > rname + 1)
while ((--dest)[-1] != '/');
}
else
@@ -213,26 +215,26 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
if (dest[-1] != '/')
*dest++ = '/';
- if (dest + (end - start) >= rpath_limit)
+ if (dest + (end - start) >= rname_limit)
{
- ptrdiff_t dest_offset = dest - rpath;
- size_t new_size = rpath_limit - rpath;
+ ptrdiff_t dest_offset = dest - rname;
+ size_t new_size = rname_limit - rname;
if (end - start + 1 > PATH_MAX)
new_size += end - start + 1;
else
new_size += PATH_MAX;
- rpath = xrealloc (rpath, new_size);
- rpath_limit = rpath + new_size;
+ rname = xrealloc (rname, new_size);
+ rname_limit = rname + new_size;
- dest = rpath + dest_offset;
+ dest = rname + dest_offset;
}
dest = memcpy (dest, start, end - start);
dest += end - start;
*dest = '\0';
- if (lstat (rpath, &st) < 0)
+ if (lstat (rname, &st) != 0)
{
if (can_mode == CAN_EXISTING)
goto error;
@@ -255,7 +257,7 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
goto error;
}
- buf = xreadlink (rpath, st.st_size);
+ buf = xreadlink (rname, st.st_size);
if (!buf)
{
if (can_mode == CAN_MISSING)
@@ -284,10 +286,10 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
name = end = memcpy (extra_buf, buf, n);
if (buf[0] == '/')
- dest = rpath + 1; /* It's an absolute symlink */
+ dest = rname + 1; /* It's an absolute symlink */
else
/* Back up to previous component, ignore if at root already: */
- if (dest > rpath + 1)
+ if (dest > rname + 1)
while ((--dest)[-1] != '/');
free (buf);
@@ -302,15 +304,15 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
}
}
}
- if (dest > rpath + 1 && dest[-1] == '/')
+ if (dest > rname + 1 && dest[-1] == '/')
--dest;
*dest = '\0';
free (extra_buf);
- return rpath;
+ return rname;
error:
free (extra_buf);
- free (rpath);
+ free (rname);
return NULL;
}
@@ -161,38 +163,38 @@ canonicalize_filename_mode (const char *name, canonicalize_mode_t can_mode)
for (start = end = name; *start; start = end)
{
- /* Skip sequence of multiple path-separators. */
+ /* Skip sequence of multiple file name separators. */
while (*start == '/')